@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/11/13 12:21:38 $
-# $Revision: 1.18.1.177 $
+# $Date: 1998/11/13 14:53:01 $
+# $Revision: 1.18.1.178 $
 #
 #
 package provide zircon 1.18
@@ -429,6 +429,7 @@ proc channel_handleOV {this ov usr} {
 }
 #
 proc setOption {this sub opt val} {
+    switch {} $val return
     switch *default* [$this lname] {
 	set id *${sub}[capitalise $opt]
     } default {
@@ -483,9 +484,10 @@ for regular expression \"$v\" in -ban for channel [$this name]"
 	-foreground -
 	-background -
 	-font {
-		set cdata($opt) $val
-		setOption $this {} $opt $val
-		if {[$this active]} { [$this text] configure $name $val }
+		switch {} [set cdata($opt) $val] {} default {
+		    setOption $this {} $opt $val
+		    if {[$this active]} { [$this text] configure $name $val }
+		}
 	    }
 	-geometry {
 		set cdata($opt) $val
