@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Notrace.tcl,v $
-# $Date: 1998/10/28 10:23:12 $
-# $Revision: 1.18.1.29 $
+# $Date: 1998/11/06 10:07:36 $
+# $Revision: 1.18.1.31 $
 #
 #
 package provide Notrace 1.18
@@ -94,41 +94,8 @@ proc net_q1Send {this op} {
     return 0
 }
 #
-proc SOCKSet {host port} {
-    global zircon SOCKSwait
-    if {[set match [scan $host "%d.%d.%d.%d" a b c d]] != 4} {
-        error "SOCKS ERROR: Host must be IP address, not name"
-    }
-
-    set sk [socket $zircon(sockshost) $zircon(socksport)]
-    puts -nonewline $sk [binary format "ccScccca*c" 4 1 $port $a $b $c $d $sname 0]
-    flush $sk
-
-    fileevent $sk readable "SOCKSreply $sk"
-    set SOCKSwait($sk) 0
-    vwait SOCKSwait($sk)
-    if {[set r $SOCKSwait($sk)] != "90"} {
-        unset SOCKSwait($sk)
-	error "SOCKS Request failed code : $r"
-    }
-    unset SOCKSwait($sk)
-    return $sk
-}
-#
-proc SOCKSreply {sk} {
-    global SOCKSwait
-    binary scan [read $sk 8] "ccSI" v r port ip
-    set SOCKSwait($sk) $r
-}
-#
-proc connect {host port} {
-    global zircon
-    if {[info exists zircon(sockshst)]} {
-        set scmd SOCKSet
-    } {
-        set scmd socket
-    }
-    set sk [$scmd $host $port]
+proc net_connect {this host port} {
+    set sk [[$this sockcmd] $host $port]
     sconf $sk {}
     return $sk
 }
