@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Server.tcl,v $
-# $Date: 1998/07/10 13:33:52 $
-# $Revision: 1.18.1.30 $
+# $Date: 1998/10/30 10:32:44 $
+# $Revision: 1.18.1.31 $
 #
 #
 package provide zircon 1.18
@@ -69,12 +69,6 @@ proc server_configure {this args} {
     }
 }
 #
-#proc server_call {this op args} {
-#   upvar #0 $this sdata
-#   if {[info exists sdata($op)]} { return $sdata($op) }
-#   return [eval server_$op $this $args ]
-#}
-#
 proc server_delete {this} {
     uplevel #0 unset STO\${currentNet}([string tolower [$this name]]) $this
     uplevel #0 \$currentNet deregister servers $this
@@ -121,7 +115,7 @@ proc Server_save {desc net} {
 	    }
 	    append ln " -port $pl"
 	}
-	foreach x {oper operpw script passwd} {
+	foreach x {ip oper operpw script passwd} {
 	    switch {} [set y [$id $x]] {} default {append ln " -$x [list $y]"}
 	}
 	foreach x {invisible wallops srvmsg undernet} {
@@ -153,7 +147,7 @@ proc Server_make {net host} {
 #
 proc server_pack {this net} {
     upvar #0 new$this new
-    foreach v {host port oper operpw script name passwd invisible wallops srvmsg} {
+    foreach v {host port ip oper operpw script name passwd invisible wallops srvmsg} {
 	set new($v) [$this $v]
     }
     global ${net}STO
@@ -162,7 +156,7 @@ proc server_pack {this net} {
 #
 proc server_unpack {this net} {
     upvar #0 new$this new ${net}STO STO
-    foreach v {host port oper operpw passwd script invisible wallops srvmsg} {
+    foreach v {host port ip oper operpw passwd script invisible wallops srvmsg} {
 	$this configure -$v $new($v)
     }
     unset STO([string tolower $new(name)]) new
