@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Undernet.tcl,v $
-# $Date: 1998/05/07 11:01:24 $
-# $Revision: 1.18.1.13 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Undernet.tcl,v $
+# $Date: 1998/07/10 13:33:53 $
+# $Revision: 1.18.1.14 $
 #
 package provide zircon 1.18
 #
@@ -23,9 +23,7 @@ proc irc006 {net prefix param pargs} {
 proc irc007 {net prefix param pargs} {
     global umap
     if {![winfo exists [set w .@map$net]]} {
-	toplevel $w -class Zircon
-	wm title $w "Undernet Map from [$net host]"
-	wm resizable $w 1 1
+	makeToplevel $w "Undernet Map from [$net host]" {} {}
 	scrollbar $w.vs -command "$w.txt yview"
 	scrollbar $w.hs -command "$w.txt xview" -orient horizontal
 	text $w.txt -yscrollcommand "$w.vs set" -wrap none \
@@ -98,10 +96,8 @@ proc irc249 {net prefix param pargs} {
 proc underflags {net} {
     if {[winfo exists [set w .@und$net]]} { popup $w ; return }
     global underflags zircon
-    toplevel $w -class Zircon
-    wm title $w "Server message flags for [$net name]"
+    makeToplevel $w "Server message flags for [$net name]" "underreset $net" {}
     wm resizable $w 0 0
-    wm protocol $w WM_DELETE_WINDOW "underreset $net"
     upvar #0 und$net und undt$net tmp
     array set tmp [array get und]
     set row 0
