@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/saverc.tcl,v $
-# $Date: 1998/06/11 08:42:53 $
-# $Revision: 1.18.1.27 $
+# $Date: 1998/11/06 10:07:46 $
+# $Revision: 1.18.1.30 $
 #
 package provide zircon 1.18
 #
@@ -44,7 +44,7 @@ proc saverc {net} {
     if {[file exist $rc]} {
 	file stat $rc st
 	set mode $st(mode)
-	set rc [glob $rc]
+	set rc [lindex [glob $rc] 0]
 	filerename $rc $rc.bak
 	set bak 1
     } {
@@ -76,6 +76,18 @@ proc saverc {net} {
     return 1
 }
 #
+proc saveSocks {desc dflt net} {
+    global defaultNet
+    switch {} [set sh [$net sockshost]] {} default {
+        if {!$dflt} { switch [$defaultNet sockshost] $sh return }
+        set l "usesocks [list $sh]"
+	switch --  [$net socksport] 1080 {} default {
+	    append l " [$net socksport]"
+	}
+	puts $desc "$l\n#"
+    }
+}
+#
 proc doSave {dflt net desc} {
     global zircon defaults DEBUG trust RCFV defaultNet user Configure.Net
     if {$dflt} {
@@ -87,6 +99,10 @@ proc doSave {dflt net desc} {
 # Save things that are different from the default...
 #
     puts $desc "preferences format $RCFV"
+#
+# save SOCKS information
+#
+    saveSocks $desc $dflt $net
     if {$dflt} {
 	foreach z [array names defaults] {
 	    switch -- $zircon($z) $defaults($z) {} default {
@@ -198,7 +214,7 @@ proc saveLayout {net} {
     if {[file exist $rc]} {
 	file stat $rc st
 	set mode $st(mode)
-	set rc [glob $rc]
+	set rc [lindex [glob $rc] 0]
 	if {[catch {filerename $rc $rc.bak} msg]} {
 	    tellError {} Error "Error when renaming $rc - $msg"
 	    return 0
