@@ -1,7 +1,7 @@
 #
 # This file defines some values that control the look of the standard
 # Zircon. This is just the start of the changes and this not what it will
-# all be like in the future!!! I will let you know when it is save to
+# all be like in the future!!! I will let you know when it is safe to
 # start tinkering with it...
 #
 array set Ops {
@@ -10,6 +10,6 @@ array set Ops {
     user	{Who Whois Whowas Mode CTCP DCC Invite Message Notice \
 	         Finger Time Trace Userhost}
     ircop	{Kill}
-    userMenu {Whois Message Notice Time CTCP DCC Notify Ignore Finger}
+    userMenu {Whois Message Notice Time CTCP DCC Notify Ignore Silence Finger}
     chanop	{Speak ChanOp Kick Ban BanKick}
 }
